import { StrictMode, Suspense, lazy } from 'react';
import { createRoot } from 'react-dom/client';
import { createBrowserRouter, RouterProvider } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import App from './App.tsx';
import { NotFoundPage } from './pages/NotFoundPage.tsx';
import { RootLayout } from './components/layout/RootLayout.tsx';
import './index.css';
// i18n kutubxonasi import qilish
import './i18n';

// Lazy load pages for better performance
const WafPage = lazy(() => import('./pages/WafPage.tsx').then(module => ({ default: module.WafPage })));
const PricingPage = lazy(() => import('./pages/PricingPage.tsx').then(module => ({ default: module.PricingPage })));
const ContactPage = lazy(() => import('./pages/ContactPage.tsx').then(module => ({ default: module.ContactPage })));
const TrialPage = lazy(() => import('./pages/TrialPage.tsx').then(module => ({ default: module.TrialPage })));
const BlogPage = lazy(() => import('./pages/BlogPage.tsx').then(module => ({ default: module.BlogPage })));
const BlogDetailPage = lazy(() => import('./pages/BlogDetailPage.tsx').then(module => ({ default: module.BlogDetailPage })));

// Loading component
const PageLoading = () => (
  <div className="min-h-screen bg-black text-white flex items-center justify-center">
    <div className="inline-block h-12 w-12 animate-spin rounded-full border-4 border-solid border-purple-500 border-r-transparent"></div>
  </div>
);

// Создаем маршруты для языковых версий
const createRoutes = (langPrefix = '') => [
  {
    path: langPrefix ? `/${langPrefix}` : "/",
    element: (
      <RootLayout>
        <App />
      </RootLayout>
    ),
    errorElement: <NotFoundPage />,
  },
  {
    path: langPrefix ? `/${langPrefix}/waf` : "/waf",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <WafPage />
        </Suspense>
      </RootLayout>
    ),
  },
  {
    path: langPrefix ? `/${langPrefix}/pricing` : "/pricing",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <PricingPage />
        </Suspense>
      </RootLayout>
    ),
  },
  {
    path: langPrefix ? `/${langPrefix}/contact` : "/contact",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <ContactPage />
        </Suspense>
      </RootLayout>
    ),
  },
  {
    path: langPrefix ? `/${langPrefix}/trial` : "/trial",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <TrialPage />
        </Suspense>
      </RootLayout>
    ),
  },
  {
    path: langPrefix ? `/${langPrefix}/blog` : "/blog",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <BlogPage />
        </Suspense>
      </RootLayout>
    ),
  },
  {
    path: langPrefix ? `/${langPrefix}/blog/:slug` : "/blog/:slug",
    element: (
      <RootLayout>
        <Suspense fallback={<PageLoading />}>
          <BlogDetailPage />
        </Suspense>
      </RootLayout>
    ),
  },
];

// Объединяем маршруты для всех языков
const router = createBrowserRouter([
  // Маршруты для базового языка (узбекский)
  ...createRoutes(),
  
  // Маршруты для русского языка
  ...createRoutes('ru'),
  
  // Маршруты для английского языка
  ...createRoutes('en'),
  
  // Обработка несуществующих маршрутов
  {
    path: "*",
    element: <NotFoundPage />,
  }
]);

// Register performance measuring
if ('performance' in window && process.env.NODE_ENV === 'production') {
  window.addEventListener('load', () => {
    // Wait until the page is fully loaded to measure
    setTimeout(() => {
      const perfData = window.performance.timing;
      const pageLoadTime = perfData.loadEventEnd - perfData.navigationStart;
      console.info(`Sahifa ${pageLoadTime}ms vaqtda yuklandi`);
    }, 0);
  });
}

// Microsoft Clarity инициализируется через скрипт в index.html

createRoot(document.getElementById('root')!).render(
  <StrictMode>
    <HelmetProvider>
      <RouterProvider router={router} />
    </HelmetProvider>
  </StrictMode>
);
